@@ -34,7 +34,7 @@ static GParamSpec *props[PROP_LAST_PROP];
 /**
  * PosCompleterPipe:
  *
- * A completer using a unix pipe like approach.
+ * A completer using a Unix pipe like approach.
  *
  * This completer feeds the preedit to standard input
  * of the given executable and reads the possible completioins
@@ -207,7 +207,7 @@ pos_completer_pipe_initable_init (GInitable    *initable,
   g_autoptr (GError) err = NULL;
   g_autofree char *path = NULL;
   gboolean found;
-  char *command;
+  g_autofree char *command = NULL;
 
   command = g_settings_get_string (self->settings, "command");
   if (g_shell_parse_argv (command, NULL, &self->command, &err) == FALSE) {
