@@ -427,7 +427,14 @@ pos_completer_add_preedit (PosCompleter *self, GString *preedit, const char *sym
   return FALSE;
 }
 
-
+/**
+ * pos_completer_get_display_name:
+ * @self: The completer
+ *
+ * Get the completers display name
+ *
+ * Returns:(transfer full): The display name
+ */
 char *
 pos_completer_get_display_name (PosCompleter *self)
 {
@@ -555,9 +562,8 @@ pos_completer_grab_last_word (const char *text, char **new_text, char **word)
  * Returns: (transfer full): copy of completions with changed capitalization
  */
 GStrv
-pos_completer_capitalize_by_template (const char *template, const GStrv completions)
+pos_completer_capitalize_by_template (const char  *template, const GStrv  completions)
 {
-  int i;
   gboolean has_caps;
   glong templ_len;
   g_autoptr (GStrvBuilder) builder = NULL;
@@ -569,7 +575,7 @@ pos_completer_capitalize_by_template (const char *template, const GStrv completi
   utemplate = g_utf8_to_ucs4_fast (template, -1, &templ_len);
 
   has_caps = FALSE;
-  for (i = 0; i < templ_len; i++) {
+  for (int i = 0; i < templ_len; i++) {
     if (g_unichar_isupper (utemplate[i])) {
       has_caps = TRUE;
       break;
@@ -580,7 +586,7 @@ pos_completer_capitalize_by_template (const char *template, const GStrv completi
 
   builder = g_strv_builder_new ();
 
-  for (i = 0; i < g_strv_length (completions); i++) {
+  for (int i = 0; i < g_strv_length (completions); i++) {
     glong read_len, compl_len, read, written;
     g_autofree gunichar *ucompletion = NULL;
     g_autofree char *new_completion = NULL;
