@@ -858,11 +858,11 @@ pos_input_surface_move (PosInputSurface *self)
   }
 
   if (self->animation.show) {
-    gtk_widget_show (GTK_WIDGET (self));
+    gtk_widget_set_visible (GTK_WIDGET (self), TRUE);
   } else if (self->animation.progress >= 1.0 && !self->animation.show) {
     GtkWidget *widget;
 
-    gtk_widget_hide (GTK_WIDGET (self));
+    gtk_widget_set_visible (GTK_WIDGET (self), FALSE);
     widget = hdy_deck_get_visible_child (self->deck);
     if (POS_IS_OSK_WIDGET (widget))
       pos_osk_widget_set_layer (POS_OSK_WIDGET (widget), POS_OSK_WIDGET_LAYER_NORMAL);
@@ -932,6 +932,16 @@ pos_input_surface_set_completer (PosInputSurface *self, PosCompleter *completer)
 }
 
 
+static void
+on_default_completer_changed (PosInputSurface *self)
+{
+  /* Handle completer change as layout switch as it will recheck the
+   * completer to be used */
+  g_debug ("Default completer changed, updating layout");
+  on_visible_child_changed (self);
+}
+
+
 static void
 pos_input_surface_set_completer_manager (PosInputSurface     *self,
                                          PosCompleterManager *completer_manager)
@@ -939,10 +949,20 @@ pos_input_surface_set_completer_manager (PosInputSurface     *self,
   if (self->completer_manager == completer_manager)
     return;
 
+  if (self->completer_manager)
+    g_signal_handlers_disconnect_by_data (self->completer_manager, self);
+
   g_set_object (&self->completer_manager, completer_manager);
 
+  if (self->completer_manager) {
+    g_signal_connect_swapped (self->completer_manager,
+                              "notify::default",
+                              G_CALLBACK (on_default_completer_changed),
+                              self);
+  }
+
   /* Switch completion */
-  if (self->last_layout)
+  if (self->last_layout && self->completer_manager)
     pos_input_surface_switch_completion (self, POS_OSK_WIDGET (self->last_layout));
 }
 
@@ -1008,6 +1028,7 @@ pos_input_surface_set_osk_features (PosInputSurface *self, PhoshOskFeatures osk_
 
   self->osk_features = osk_features;
   g_hash_table_foreach (self->osks, update_osk_features, self);
+  pos_osk_widget_set_features (POS_OSK_WIDGET (self->osk_terminal), self->osk_features);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_OSK_FEATURES]);
 }
@@ -1333,7 +1354,7 @@ pos_input_surface_finalize (GObject *object)
   g_clear_object (&self->xkbinfo);
   g_clear_object (&self->clipboard_manager);
   g_clear_object (&self->completer);
-  g_clear_object (&self->completer_manager);
+  pos_input_surface_set_completer_manager (self, NULL);
   g_clear_object (&self->swipe_down);
   g_clear_object (&self->style_manager);
   g_clear_pointer (&self->osks, g_hash_table_destroy);
@@ -1504,7 +1525,7 @@ pos_input_surface_class_init (PosInputSurfaceClass *klass)
   g_type_ensure (POS_TYPE_SHORTCUTS_BAR);
 
   gtk_widget_class_set_template_from_resource (widget_class,
-                                               "/mobi/phosh/osk-stub/ui/input-surface.ui");
+                                               "/mobi/phosh/stevia/ui/input-surface.ui");
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, completion_bar);
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, deck);
   gtk_widget_class_bind_template_child (widget_class, PosInputSurface, emoji_picker);
